<?php

add_action( 'admin_menu', 'essential_breadcrumbs_setup' );

function essential_breadcrumbs_setup() {
    add_submenu_page( 'options-general.php', 'Essential Marketer Breadcrumbs', 'Essential Breadcrumbs', 'manage_options', 'essential-breadcrumbs', 'essential_breadcrumbs' );
}

function essential_breadcrumbs() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}

	$saved = 'no';

	if( $_POST ):
		if( isset($_POST["save_emb_settings"]) ):

			unset($_POST["save_emb_settings"]);

			foreach( $_POST as $key => $value ):
				update_option( $key, $value );
			endforeach;

			$saved = 'yes';

		endif;
	endif;

	$emb_text = get_option('emb_text');
	$emb_breadcrumb_seperator = get_option('emb_breadcrumb_seperator');
	$emb_custom_css = get_option('emb_breadcrumb_custom_css');
	?>
	<div class="wrap">
		<h1>Essential Marketer Breadcrumbs</h1>
		<?php if( $saved == 'yes' ): ?>
			<div class="success">Settings Saved!</div>
		<?php endif; ?>
		<div class="essential-breadecrumbs-options">
			<form action="<?php echo $_SERVER["REQUEST_URI"]; ?>" method="post">
				<h3>Text before breadcrumbs</h3>
				<div class="input-section">
					<input type="text" name="emb_text" value="<?php echo $emb_text; ?>" />
				</div>
				<h3>Breadcrumb seperator</h3>
				<div class="input-section">
					<input type="text" name="emb_breadcrumb_seperator" value="<?php echo $emb_breadcrumb_seperator; ?>" />
				</div>
				<h3>Shortcode</h3>
				<div class="input-section">
					<p>To add the breadcrumbs to a particular page, copy and paste the following shortcode into the page content <b>[emb]</b></p>
					<p>To add the breadcrumbs to a page template, copy and paste the following into the template <b>&lt;?php echo do_shortcode('[emb]'); ?&gt;</b></p>
				</div>
				<h3>Custom CSS</h3>
				<div class="input-section">
					<textarea name="emb_breadcrumb_custom_css" value="" style="width:100%; height:350px;" /><?php echo $emb_custom_css; ?></textarea>
				</div>
				<div class="input-section">
					<input  class="button button-primary button-large" type="submit" name="save_emb_settings" value="Save Settings" />
				</div>
			</form>
		</div>
	</div>
	<?php
}

function add_meta_boxes_page(){
	add_meta_box( 'essential-breadcrumbs-meta-box', __( 'Essential Breadcrumbs Title' ), 'render_essential_breadcrumbs_meta_box', 'page', 'normal', 'default' );
}
add_action( 'add_meta_boxes', 'add_meta_boxes_page' );

function add_meta_boxes_post(){
	add_meta_box( 'essential-breadcrumbs-meta-box', __( 'Essential Breadcrumbs Title' ), 'render_essential_breadcrumbs_meta_box', 'post', 'normal', 'default' );
}
add_action( 'add_meta_boxes', 'add_meta_boxes_post' );

function render_essential_breadcrumbs_meta_box(){

	global $post;

	$value = get_post_meta( $post->ID, 'essential_breadcrumbs_title', true );

	$output = '<p>If this field is left empty, the title of the page entered at the top will automatically be used.</p>';
	$output .= '<input type="text" id="essential-breadcrumbs-title" name="essential-breadcrumbs-title" value="' . esc_attr( $value ) . '" style="width:100%" />';

	echo $output;
}

function essential_breadcrumbs_save_meta_box_data( $post_id ) {

	// Few checks
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
		return;
	}

	if ( !current_user_can( 'edit_page', $post_id ) ){
		return;
	}

	if ( ! isset( $_POST['essential-breadcrumbs-title'] ) ) {
		return;
	}

	//Checks passed, lets save the data
	$breadcrumbs_title = sanitize_text_field( $_POST['essential-breadcrumbs-title'] );
	update_post_meta( $post_id, 'essential_breadcrumbs_title', $breadcrumbs_title );
}
add_action( 'save_post', 'essential_breadcrumbs_save_meta_box_data' );